<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="sv">
<context>
    <name>Cmd</name>
    <message>
        <location filename="../src/cmd.cpp" line="141"/>
        <source>Administrator Access Required</source>
        <translation>Administratöråtkomst Krävs</translation>
    </message>
    <message>
        <location filename="../src/cmd.cpp" line="142"/>
        <source>This operation requires administrator privileges. Please restart the application and enter your password when prompted.</source>
        <translation>Denna operation kräver administratörprivilegier. Var vänlig starta om programmet och skriv in ditt lösenord när du blir uppmanad.</translation>
    </message>
</context>
<context>
    <name>CustomDialog</name>
    <message>
        <location filename="../src/dialog.cpp" line="16"/>
        <source>Live environment detected. Please select the root partition of the
 system you want to modify (only Linux partitions are displayed)</source>
        <translation>Live-miljö upptäckt. Var vänlig välj root-partitionen på det
system du vill modifiera (enbart Linux-partitioner visas)</translation>
    </message>
    <message>
        <location filename="../src/dialog.cpp" line="22"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../src/dialog.cpp" line="23"/>
        <source>Cancel</source>
        <translation>Avbryt</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/mainwindow.ui" line="33"/>
        <source>Options</source>
        <translation>Valmöjligheter</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="39"/>
        <source>Use simplified menu structure without submenus</source>
        <translation>Använd förenklad menystruktur utan undermenyer</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="42"/>
        <source>Use flat menus (no submenus)</source>
        <translation>Använd enkla menyer (inga undermenyer)</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="55"/>
        <source>Boot to</source>
        <translation>Starta till</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="78"/>
        <source>Set to &apos;0&apos; to boot immediately without displaying the menu, or to &apos;-1&apos; to wait indefinitely</source>
        <translation>Sätt värdet till &apos;0&apos; för att starta omedelbart utan att visa menyn, eller till &apos;-1&apos; för att vänta utan tidsgräns.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="81"/>
        <source>Menu timeout</source>
        <translation>Meny timeout</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="104"/>
        <source>Kernel parameters</source>
        <translation>Kernel parametrar</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="117"/>
        <source>seconds</source>
        <translation>sekunder</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="124"/>
        <source>With this option enabled whatever entry you select from the grub boot menu will be saved as the new default for future boots</source>
        <translation>Med detta alternativ aktiverat, vad du än väljer från grub startmeny kommer att sparas som standard för framtida starter.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="127"/>
        <source>Enable saving last boot choice</source>
        <translation>Aktivera sparande av senaste startval</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="134"/>
        <source>Manage UEFI Boot Options</source>
        <translation>Hantera UEFI Boot Alternativ</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="150"/>
        <source>Background</source>
        <translation>Bakgrund</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="168"/>
        <source>Image</source>
        <translation>Bild</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="181"/>
        <location filename="../src/mainwindow.ui" line="283"/>
        <source>Enable theme</source>
        <translation>Aktivera tema</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="261"/>
        <source>Splash</source>
        <translation>Splash</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="296"/>
        <source>Preview</source>
        <translation>Förhandsvisning</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="319"/>
        <source>Messages</source>
        <translation>Meddelanden</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="325"/>
        <source>Very detailed</source>
        <translation>Mycket detaljerat</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="332"/>
        <source>Detailed (default setting)</source>
        <translation>Detaljerad (standardinställning)</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="342"/>
        <source>Limited</source>
        <translation>Begränsad</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="358"/>
        <source>Display log</source>
        <translation>Visa logg</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="411"/>
        <source>Display help </source>
        <translation>Visa hjälp</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="414"/>
        <source>Help</source>
        <translation>Hjälp</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="421"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="453"/>
        <source>About this application</source>
        <translation>Om detta program</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="456"/>
        <source>About...</source>
        <translation>Om...</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="463"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="498"/>
        <source>Quit application</source>
        <translation>Avsluta programmet</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="501"/>
        <source>Close</source>
        <translation>Stäng</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="508"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="549"/>
        <source>Apply</source>
        <translation>Använd</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="100"/>
        <source>Still running</source>
        <translation>Kör fortfarande</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="402"/>
        <location filename="../src/mainwindow.cpp" line="410"/>
        <location filename="../src/mainwindow.cpp" line="444"/>
        <location filename="../src/mainwindow.cpp" line="555"/>
        <location filename="../src/mainwindow.cpp" line="1399"/>
        <location filename="../src/mainwindow.cpp" line="1412"/>
        <location filename="../src/mainwindow.cpp" line="1418"/>
        <source>Error</source>
        <translation>Fel</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="391"/>
        <source>Installing bootsplash, please wait</source>
        <translation>Installerar bootsplash, var vänlig vänta</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="157"/>
        <location filename="../src/mainwindow.cpp" line="1188"/>
        <source>Preview is disabled because &apos;splash&apos; parameter is not present in kernel command line. To enable preview, add &apos;splash&apos; to boot parameters and reboot.</source>
        <translation>Förhandsvisning är  avaktiverad därför att &apos;splash&apos;-parametern inte är närvarande i kärnans kommandolinje. Lägg till &apos;splash&apos; till boot-parametrarna och starta om för att aktivera förhandsvisning.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="161"/>
        <location filename="../src/mainwindow.cpp" line="1191"/>
        <source>Preview is disabled while running under Wayland. Please start an X11 session to preview Plymouth themes.</source>
        <translation>Förhandsgranskning är avaktiverad när Wayland används. Var vänlig starta en X11 session för att förhandsgranska Plymouth-teman.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="398"/>
        <source>Updating sources</source>
        <translation>Uppdaterar källor</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="410"/>
        <source>Could not install the bootsplash.</source>
        <translation>Kunde inte installera bootsplash.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="555"/>
        <source>Could not create a temporary folder</source>
        <translation>Kunde inte skapa en temporär katalog.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="564"/>
        <location filename="../src/mainwindow.cpp" line="584"/>
        <source>Cannot continue</source>
        <translation>Kan inte fortsätta</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="564"/>
        <source>Cannot open LUKS device. Exiting...</source>
        <translation>Kan inte öppna LUKS-enhet. Avbryter...</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="585"/>
        <source>Cannot create chroot environment, cannot change boot options. Exiting...</source>
        <translation>Kan inte skapa chroot-miljö, kan inte ändra startalternativ. Avslutar...</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="917"/>
        <location filename="../src/mainwindow.cpp" line="1315"/>
        <source>Updating configuration, please wait</source>
        <translation>Uppdaterar konfiguration, var vänlig vänta</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="988"/>
        <source>Updating initramfs...</source>
        <translation>Uppdaterar initramfs...</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1002"/>
        <location filename="../src/mainwindow.cpp" line="1330"/>
        <source>Updating grub...</source>
        <translation>Uppdaterar grub...</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1027"/>
        <source>About %1</source>
        <translation>Om %1</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1028"/>
        <source>Version: </source>
        <translation>Version:</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1030"/>
        <source>Program for selecting common start-up choices</source>
        <translation>Program för att göra vanliga val vid start</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1032"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1033"/>
        <source>%1 License</source>
        <translation>%1 Licens</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1054"/>
        <source>%1 Help</source>
        <translation>%1 Hjälp</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1064"/>
        <location filename="../src/mainwindow.cpp" line="1292"/>
        <source>Running in a Virtual Machine</source>
        <translation>Kör i en Virtuell Maskin</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1065"/>
        <location filename="../src/mainwindow.cpp" line="1293"/>
        <source>You current system is running in a Virtual Machine,
Plymouth bootsplash will work in a limited way, you also won&apos;t be able to preview the theme</source>
        <translation>Ditt nuvarande system körs i en Virtuell Maskin,
Plymouth bootsplash kommer att fungera på ett begränsatt sätt, du kommer inte heller kunna förhandsgranska temat</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1072"/>
        <source>Plymouth packages not installed</source>
        <translation>Plymouth-paket ej installerade</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1073"/>
        <source>Plymouth packages are not currently installed.
OK to go ahead and install them?</source>
        <translation>Plymouth-paketen är för närvarande inte installerade.
OK att fortsätta och installera dem?</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1099"/>
        <source>Images (*.png *.jpg *.jpeg *.tga)</source>
        <translation>Bilder (*.png *.jpg *.jpeg *.tga)</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1253"/>
        <source>Log not found</source>
        <translation>Logg ej hittad</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1253"/>
        <source>Could not find log at </source>
        <translation>Kunde inte hitta logg vid</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1274"/>
        <source>Preview Unavailable</source>
        <translation>Förhandsgranskning ej tillgänglig</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1275"/>
        <source>Preview is not available while running under Wayland. Please start an X11 session to preview Plymouth themes.</source>
        <translation>Förhandsgranskning är ej tillgänglig när Wayland används. Var vänlig starta en X11 session för att förhandsgranska Plymouth-teman.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1399"/>
        <source>Could not retrieve UUID for %1</source>
        <translation>Kunde inte få UUID för %1</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1407"/>
        <source>Enter password to unlock %1 encrypted partition:</source>
        <translation>Skriv in lösenord för att låsa upp %1 krypterad partition:</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1412"/>
        <source>Password entry cancelled or empty for %1</source>
        <translation>Lösenordspost avbruten eller tom för %1</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1418"/>
        <source>Could not open %1 LUKS container</source>
        <translation>Kunde inte öppna %1 LUKS container</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1242"/>
        <source>&amp;Close</source>
        <translation>&amp;Stäng</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="101"/>
        <source>A process is still running. Do you really want to quit?</source>
        <translation>En process körs fortfarande. Vill du verkligen avsluta?</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="181"/>
        <source>Live System Detected</source>
        <translation>Live-system Upptäckt</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="183"/>
        <source>You are currently running a live system. Would you like to modify the boot options for the live system or for an installed system?</source>
        <translation>Du kör nu ett live-system. Vill du modifiera boot alternativ för live-systemet eller för ett installerat system?</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="185"/>
        <source>Live System</source>
        <translation>Live-system</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="186"/>
        <source>Installed System</source>
        <translation>Installerat system</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="402"/>
        <source>Failed to update package sources.</source>
        <translation>Kunde inte uppdatera paketförråden.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="406"/>
        <source>Installing packages:</source>
        <translation>Installerar paket:</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="416"/>
        <source>Success</source>
        <translation>Det lyckades</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="416"/>
        <source>Bootsplash installed successfully.</source>
        <translation>Bootsplash framgångsrikt installerad.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="444"/>
        <source>Failed to create temporary file.</source>
        <translation>Kunde inte skapa temporär fil.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1010"/>
        <source>You are currently running in live mode with the &apos;toram&apos; option. Please remember to save the persistence file or remaster, otherwise any changes made will be lost.</source>
        <translation>Du kör nu live mode med &apos;toram&apos; alternativet. Var vänlig kom ihåg att spara persistensfilen eller remastra, annars kommer gjorda ändringar att förloras.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1012"/>
        <source>Your changes have been successfully applied.</source>
        <translation>Dina ändringar har framgångsrikt tillämpats</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1013"/>
        <source>Operation Complete</source>
        <translation>Processen klar</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1098"/>
        <source>Select image to display in bootloader</source>
        <translation>Välj bild att visa i bootloader</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1234"/>
        <source>Boot Log</source>
        <translation>Bootlogg</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1281"/>
        <source>Needs reboot</source>
        <translation>Behöver omstart</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1282"/>
        <source>Plymouth was just installed, you might need to reboot before being able to display previews</source>
        <translation>Plymouth har just installerats, du kan behöva starta om innan du kan visa förhandsgranskningar</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1355"/>
        <source>Click to select theme</source>
        <translation>Klicka för att välja tema</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1366"/>
        <source>Select GRUB theme</source>
        <translation>Välj GRUB-tema</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <location filename="../src/main.cpp" line="64"/>
        <source>Program for selecting common start-up choices</source>
        <translation>Program för att göra vanliga val vid start</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/about.cpp" line="54"/>
        <source>License</source>
        <translation>Licens</translation>
    </message>
    <message>
        <location filename="../src/about.cpp" line="55"/>
        <location filename="../src/about.cpp" line="64"/>
        <source>Changelog</source>
        <translation>Ändringslogg</translation>
    </message>
    <message>
        <location filename="../src/about.cpp" line="56"/>
        <source>Cancel</source>
        <translation>Avbryt</translation>
    </message>
    <message>
        <location filename="../src/about.cpp" line="75"/>
        <source>&amp;Close</source>
        <translation>&amp;Stäng</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="92"/>
        <source>Error</source>
        <translation>Fel</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="93"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation>Du verkar vara inloggad som root, var vänlig logga ut och logga in som vanlig användare för att använda detta program.</translation>
    </message>
</context>
</TS>